.. currentmodule:: kombu.exceptions

.. automodule:: kombu.exceptions

    .. contents::
        :local:

    .. autoexception:: NotBoundError
    .. autoexception:: MessageStateError
    .. autoexception:: TimeoutError
    .. autoexception:: LimitExceeded
    .. autoexception:: ConnectionLimitExceeded
    .. autoexception:: ChannelLimitExceeded

